package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````9)P$"#0```!HL@```````#0`(``)
M`"@`'0`<``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(C*T`
M`(RM```%`````!````$```#@K@``X#X%".`^!0A0`@``E!(```8`````$```
M`@```.RN``#L/@4([#X%"!`!```0`0``!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&10IP``4"<%"%`G!0CL````[`````0`
M```$````4>5T9```````````````````````````!@````0```!2Y71DX*X`
M`.`^!0C@/@4((`$``"`!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```!`````$````%`````,```!'
M3E4`S1^_$7FS':LUTL'-[5_W"O99ZBYA````:P```````````````````#X`
M`````````````#8`````````*P```$`````:`````````"`````9````4```
M```````0````60```$P````[````90```&$````J````.```````````````
M#P```%X```!!``````````````!@````:0```"D````W`````````$D```!J
M`````````#$`````````,P`````````#````50```$@```!#````````````
M``!B````$0```$<````6``````````````!H````'P```"T````B````````
M```````)`````````"8`````````````````````````!P```$(````_````
M.@```",```!+``````````````!4````9@```"<````%````/`````8````R
M`````````$4```````````````````!-````70`````````H````6@```"4`
M``!$````3@```"P``````````````````````````````%@`````````````
M`````````````````%(```````````````(`````````````````````````
M``````````!7````$@```!,`````````````````````````3P``````````
M````#0``````````````'````&0```!;`````````!4```!<`````````%\`
M```````````````````;````"```````````````%````"\`````````````
M`!X``````````````!@``````````0```&,```!6````-```````````````
M4P```#D````=````9P````````!&`````````"$````````````````````]
M```````````````N````#`````````````````````````````````````H`
M````````````````````````40``````````````)````!<````P````2@``
M```````````````````````$````-0`````````.````"P```"4```!&````
M"`````@`````'!`$)4`$@C@!0`&BA@&HP`$``DLH!"DXHC)'B@0("$8```!(
M````````````````````2@```$P```!-`````````$X```!/````40```%(`
M``!3````5`````````!6``````````````!7````6````%L`````````````
M`%P```!>````7P```&$`````````8P```&4``````````````&<```!H````
M:0````````#(U;)Q6>CM[,[>1RVCX/M)ZM/O#J?=HVLOQ9NVV\WCGH?YG(%6
MI)N6:PE#UCGRBQP-.I<+Q8D%D`P4XIZ)!W#3(?_D#@N*$%?$N9Q`:G^:?+,!
MBV]_J9R;;L7?']EQ6!R[XY)\K$OCP-5DU'S@IP(*,V+;[7KP2FMGK\QF0D75
M[.-'Q@%]08[%P^4_+/JA;&"YC?$.`````````````````````.H"````````
M`````!(```"0`P`````````````2````)P(`````````````$@````P`````
M`````````"`````Q!``````````````2````@0,`````````````$@```$\!
M`````````````!(````%`P`````````````2````S@``````````````$@``
M`/$"`````````````!(```"J```````````````2````2@$`````````````
M$@```*$"`````````````!(````^`P`````````````2````L@(`````````
M````$@```+,!`````````````!(```!.`P`````````````2````10,`````
M````````$@```',!`````````````!(```#<```````````````2````_0$`
M````````````$@```)H!`````````````!(```!P`@`````````````2````
M'P(`````````````$@```,X"`````````````!(```#J`0`````````````2
M````OP(`````````````$@```/8!`````````````!(```"!`0``````````
M```2````50,`````````````$@```"@``````````````"````""`@``````
M```````2````8@,`````````````$@```',``````````````!(```#<`@``
M```````````2````EP,`````````````$@```!@"`````````````!(````*
M`0`````````````2````N0``````````````$@```*@!`````````````!(`
M``#C`@`````````````2````N0(`````````````$@```(\"````````````
M`!(```!``@`````````````2````QP(`````````````$@```&4`````````
M`````!(```!4`0`````````````2````#`,`````````````$@```-\!````
M`````````!(````7`0`````````````2````B0,`````````````$@```#,!
M`````````````!(```#5`@`````````````2````P0$`````````````$@``
M`#<``````````````"````#N```````````````2````D0$`````````````
M$@```&D#`````````````!(```#W`@`````````````2````@@``````````
M````$@```$L``````````````"````"'`@`````````````2````+0,`````
M````````$@```"P"`````````````!(````:`P`````````````2````40(`
M````````````$@```)@"`````````````!(````E`P`````````````2````
M<P,`````````````$@```&`!``#@F`0(`````!(```"I!```6,@$"`0````1
M`!``7P0``""W!`AP"P``$@`.`+`$``#0LP0(KP$``!(`#@`(!```1,@$"```
M```2``\`JP,``$!!!0@$````(0`:``X$``#@L`0(!0```!(`#@"/!```T,<$
M"&$````2``X`F0```*"9!`@`````$@```"@!``!(004(!````!$`&@!L!```
M($$%"``````0`!D`-P,``$1!!0@$````$0`:`&X$```@004(`````"``&0"J
M`P``0$$%"`0````A`!H`_@,``$#(!`@"````$@`.`)\$```L004(!````!$`
M&0#%!```\+`$",4!```2``X`_0```$Q!!0@!````$0`:`*D#``!`004(!```
M`!$`&@"D`P``@)H$".0!```2``X`Y`0``("U!`A$````$@`.`!\$``#0M00(
M)````!(`#@`Z!```P,8$"',````2``X`N@,``#!!!0@`````$``:`,8#``!T
M404(`````!``&@!A`@``7,@$"`0````1`!``#@4``)#"!`@K!```$@`.`'D$
M```0L`0(P0```!(`#@!R!```9)P$"``````2``X`SP$``+"6!`@`````$@``
M`%,$``#PL@0(X````!(`#@"S`P``,$$%"``````0`!D`1@0``,"R!`@M````
M$@`.`/($``!`QP0(20```!(`#@"]!```<*\$"#0````2``X`T@0```"V!`@2
M`0``$@`.`+\$``#\E00(`````!(`#```;&EB<&5R;"YS;P!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R
M0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S
M971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L
M86=S`%!,7W1H<E]K97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R
M;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!L<V5E:S8T`')E860`<'1H<F5A
M9%]G971S<&5C:69I8P!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`&QI8F,N<V\N
M-@!?24]?<W1D:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC
M;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`
M;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M
M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC
M<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E
M='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D
M9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L
M:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?
M96YD`"]U<W(O;&EB+W!E<FPU+S4N,3@N,2]I-3@V+6QI;G5X+71H<F5A9"UM
M=6QT:2]#3U)%`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E
M=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E
M;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L
M`%]F<%]H=P!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%2
M7T-,14%24U1!0TL`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'
M3$E"0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT````
M`@`"``,````"``(``@`"`````@``````!``"``(````"``(````````````%
M``8``@````(``@````<````"``(````"``(`!@`````````"``(``@`#``(`
M``````<```````(````"````````````"``'```````"``@``P`(``,``@`"
M``<````!``$``0`!``(``0`!```````!``(``0`"``$``0`!`````@`!``$`
M`0`!``$``0`!``$``0`!`````0`!``$``0`!``$``0`!``(`"`(``!`````P
M````$FEI#0``!@`D!0``$````!!I:0T```,`+@4````````!``4`5P(``!``
M````````$FEI#0``"``D!0``$````'09:0D```<`.`4``!````!R&6D)```%
M`$0%```0````%&EI#0``!`!0!0``$````!!I:0T```(`+@4```````#\/P4(
M!A\``$!!!0@%6```1$$%"`51``!(004(!4\``$Q!!0@%5P``#$`%"`<!```0
M0`4(!P(``!1`!0@'`P``&$`%"`<%```<0`4(!P8``"!`!0@'!P``)$`%"`<(
M```H0`4(!PD``"Q`!0@'8P``,$`%"`<*```T0`4(!PL``#A`!0@'#```/$`%
M"`<-``!`0`4(!PX``$1`!0@'#P``2$`%"`<0``!,0`4(!Q$``%!`!0@'$@``
M5$`%"`<3``!80`4(!Q0``%Q`!0@'%0``8$`%"`<6``!D0`4(!Q<``&A`!0@'
M&```;$`%"`<9``!P0`4(!QH``'1`!0@'&P``>$`%"`<<``!\0`4(!QT``(!`
M!0@''@``A$`%"`<?``"(0`4(!R```(Q`!0@'(0``D$`%"`<B``"40`4(!R,`
M`)A`!0@')```G$`%"`<E``"@0`4(!R8``*1`!0@')P``J$`%"`<H``"L0`4(
M!RD``+!`!0@'*@``M$`%"`<K``"X0`4(!T8``+Q`!0@'+```P$`%"`<M``#$
M0`4(!RX``,A`!0@'+P``S$`%"`<P``#00`4(!S$``-1`!0@',@``V$`%"`<S
M``#<0`4(!S0``.!`!0@'-0``Y$`%"`<V``#H0`4(!TX``.Q`!0@'.```\$`%
M"`<Y``#T0`4(!SH``/A`!0@'.P``_$`%"`<\````004(!SX```1!!0@'/P``
M"$$%"`=````,004(!T$``!!!!0@'0@``%$$%"`=#```8004(!T0``!Q!!0@'
M10``4X/L".B+!@``@</[J0``BX/\____A<!T!>CV`0``@\0(6\,`_S4$0`4(
M_R4(0`4(`````/\E#$`%"&@`````Z>#_____)1!`!0AH"````.G0_____R44
M0`4(:!````#IP/____\E&$`%"&@8````Z;#_____)1Q`!0AH(````.F@____
M_R4@0`4(:"@```#ID/____\E)$`%"&@P````Z8#_____)2A`!0AH.````.EP
M_____R4L0`4(:$````#I8/____\E,$`%"&A(````Z5#_____)31`!0AH4```
M`.E`_____R4X0`4(:%@```#I,/____\E/$`%"&A@````Z2#_____)4!`!0AH
M:````.D0_____R5$0`4(:'````#I`/____\E2$`%"&AX````Z?#^____)4Q`
M!0AH@````.G@_O___R500`4(:(@```#IT/[___\E5$`%"&B0````Z<#^____
M)5A`!0AHF````.FP_O___R5<0`4(:*````#IH/[___\E8$`%"&BH````Z9#^
M____)61`!0AHL````.F`_O___R5H0`4(:+@```#I</[___\E;$`%"&C`````
MZ6#^____)7!`!0AHR````.E0_O___R5T0`4(:-````#I0/[___\E>$`%"&C8
M````Z3#^____)7Q`!0AHX````.D@_O___R6`0`4(:.@```#I$/[___\EA$`%
M"&CP````Z0#^____)8A`!0AH^````.GP_?___R6,0`4(:``!``#IX/W___\E
MD$`%"&@(`0``Z=#]____)91`!0AH$`$``.G`_?___R680`4(:!@!``#IL/W_
M__\EG$`%"&@@`0``Z:#]____):!`!0AH*`$``.F0_?___R6D0`4(:#`!``#I
M@/W___\EJ$`%"&@X`0``Z7#]____):Q`!0AH0`$``.E@_?___R6P0`4(:$@!
M``#I4/W___\EM$`%"&A0`0``Z4#]____);A`!0AH6`$``.DP_?___R6\0`4(
M:&`!``#I(/W___\EP$`%"&AH`0``Z1#]____)<1`!0AH<`$``.D`_?___R7(
M0`4(:'@!``#I\/S___\ES$`%"&B``0``Z>#\____)=!`!0AHB`$``.G0_/__
M_R740`4(:)`!``#IP/S___\EV$`%"&B8`0``Z;#\____)=Q`!0AHH`$``.F@
M_/___R7@0`4(:*@!``#ID/S___\EY$`%"&BP`0``Z8#\____)>A`!0AHN`$`
M`.EP_/___R7L0`4(:,`!``#I8/S___\E\$`%"&C(`0``Z5#\____)?1`!0AH
MT`$``.E`_/___R7X0`4(:-@!``#I,/S___\E_$`%"&C@`0``Z2#\____)0!!
M!0AHZ`$``.D0_/___R4$004(:/`!``#I`/S___\E"$$%"&CX`0``Z?#[____
M)0Q!!0AH``(``.G@^____R40004(:`@"``#IT/O___\E%$$%"&@0`@``Z<#[
M____)1A!!0AH&`(``.FP^____R4<004(:"`"``#IH/O__U6)Y593@^3P@^PP
MC440B40D"(U%#(E$)`2-10B)!"3HG/W__\=$)`C@F`0(QT0D!."8!`C'!"2@
MF00(Z-`L``"`/4Q!!0@`=2[HHOS__X7`HW!1!0@/A'T!``")!"3H[?O__Z%(
M004(B00DZ##____&@$$%````H4A!!0B)!"3H'/___X"([@(```*A2$$%"(D$
M).@(____,=*`B.X"```!BT4(B50D'(U(!8E,)!C?;"08V`5`)P4(W05()P4(
MV<G:Z=_@G@^'!P$``,'A`HD,).AI_/__BW4,BUT(QP5H404(!````(L6@_L!
MHV11!0C'0`1%R@0(B1"+%2Q!!0C'0`Q(R@0(B5`(N@$```!^%8VT)@````"+
M#):)3)`,@\(!.=IU\L=$F`P`````@\,#B40D#*%P404(B5PD",=$)!``````
MQT0D!+"O!`B)!"3H:OW__X7`B<-T.J%P404(B00DZ#?[__^-5"0LN`G)!`CH
MB0P``(7`="RA<%$%"(D$).C8^O__Z`/]__^-9?B)V%M>7<.A<%$%"(D$).B=
M_?__B</KM:%L404(A<!T"HD$).B(*@``Z\&-5"0LN+[(!`CH.`P``(7`HVQ1
M!0ATJNO=Z!C]___'!"0!````Z+S[__\Q[5Z)X8/D\%!44FA`R`0(:-#'!`A1
M5FB`F@0(Z-O[___T9I!FD&:09I!FD(L<),-FD&:09I!FD&:09I"X,T$%""TP
M004(@_@&=P'#N`````"%P'3V58GE@^P8QP0D,$$%"/_0R<.-M@````"X,$$%
M""TP004(P?@"B<+!ZA\!T-'X=0'#N@````"%TG3V58GE@^P8B40D!,<$)#!!
M!0C_TLG#B?:-O"<`````@#U0004(`'4358GE@^P(Z'S____&!5!!!0@!R?/#
M9I"AZ#X%"(7`=!^X`````(7`=!95B>6#[!C'!"3H/@4(_]#)Z7G___^0Z7/_
M__]FD)!55U93@>Q8`0``B40D"(U('#'`D(UT)@"+%($/RHE4A!B#P`&#^!!U
M[XU4)$R-C"1,`0``C70F`(M"[(/"!#-"_#-"T#-"R,'('XE""#G*=>>+1"0(
MBW`$BU`0BQB)\8MP"(E4)!0#5"08B?6+<`R)+"2)="0$BT0D!(G>P<X;C;PR
MF7F"6HG.B>KWT2'R(<@)T(GQBU0D!`''BP0DB=T#5"0<]]7!R0*)="00(>B)
MW2'+"=B)^XVT`IEY@EJ)ZL'+&P'>BQPD`UPD((GPP<@;B6PD#,'*`HG]C9P#
MF7F"6HGX]]`AU2'(">B)]0'#B?#!SP+WT`-,)"0A_2'0">B)W8V,`9EY@EJ)
MV,'(&P'!`U0D*(G(P<@;P<X"C90"F7F"6HG8]]`A]2'X">B)S0'"B<C!RP+W
MT`-\)"PAW2'P">B)U8V\!YEY@EJ)T,'(&P''`W0D,(GXP<@;P<D"C;0&F7F"
M6HG0]]`AS2'8">B)_0'&B?C!R@+WT`-<)#0AU2'(">B)]8V<`YEY@EJ)\,'(
M&P'#`TPD.(G8P<@;P<\"C8P!F7F"6HGP]]`A_2'0">B)W0'!B=C!S@+WT`-4
M)#PA]2'X">B)S8V4`IEY@EJ)R,'(&P'"`WPD0(G0P<@;P<L"C;P'F7F"6HG(
M]]`AW2'P">B)U0''B=#!R0+WT`-T)$0AS2'8">B)_8VT!IEY@EJ)^,'(&P'&
M`UPD2(GPP<@;P<H"C9P#F7F"6HGX]]`AU2'(">B)]0'#B?#!SP+WT`-,)$PA
M_2'0">B)W8V,`9EY@EJ)V,'(&P'!`U0D4(G(P<X"P<@;(?6-E`*9>8):B=CW
MT"'X">B)S0'"B<C!RP+WT`-\)%0AW2'P">B)U8V\!YEY@EJ)T,'(&P''`W0D
M6(GXP<@;P<D"C;0&F7F"6HG0]]`AS2'8">B)_0'&B?C!R@+WT`-<)%PAU2'(
M">B)]8V<`YEY@EJ)\,'(&P'#`TPD8(G8P<@;P<\"C8P!F7F"6HGP]]`A_2'0
M">B)W0'!B=C!S@+WT`-4)&0A]2'X">B-E`*9>8):B<C!RP+!R!L!PHG8`WPD
M:#'P,<C!R0*-O`>AZ]ENB=#!R!L!^(G/`W0D;#'?,=?!R@*-O#ZAZ]ENB<;!
MSAL!_HG7`UPD<#'/,<?!R`*-O#NAZ]ENB?/!RQL!^XG'`TPD=#'7,??!S@*-
MO#FAZ]ENB=G!R1L!^8GW`U0D>(G-,<<QW\'-&\'+`HV\.J'KV6Z)Z@'ZB=\#
M1"1\,?<QS\')`HV\.*'KV6Z)T,'(&P'XB<\#M"2`````,=\QU\'*`HV\/J'K
MV6Z)QL'.&P'^B=<#G"2$````,<\QQ\'(`HV\.Z'KV6Z)\\'+&P'[B<<#C"2(
M````,=<Q]\'.`HV\.:'KV6Z)V<')&P'YB?<#E"2,````,<>)S3'?P<T;C;PZ
MH>O9;HGJ`?K!RP(#A"20````B=\Q]S'/C;PXH>O9;HG0P<D"P<@;`?B)SP.T
M))0````QWS'7P<H"C;P^H>O9;HG&P<X;`?Z)UP.<))@````QSS''P<@"C;P[
MH>O9;HGSP<L;`?N)QP.,))P````QUS'WP<X"C;PYH>O9;HG9P<D;`?F)]P.4
M)*`````QQXG-,=_!S1O!RP*-O#JAZ]ENB>H!^HG?`X0DI````#'W,<_!R0*-
MO#BAZ]ENB=#!R!L!^(G/`[0DJ````#'?,=?!R@*-O#ZAZ]ENB<;!SAL!_HG7
M`YPDK````#'/,<?!R`*-O#NAZ]ENB?/!RQL!^XG'`XPDL````#'7,??!S@*-
MO#FAZ]ENB=G!R1L!^8GW`Y0DM````#''B<TQW\'-&XV\.J'KV6Z)Z@'ZB[PD
MN````,'+`HG=(?4!QXG8"?`AR`GH`[0DO````(V\!]R\&X^)T,')`L'(&XG-
M`?B)]XG.(=T)WB'6`YPDP`````GNC;PWW+P;CXG&P<H"P<X;B=4!_HG?B=,A
MS0G+(<,#C"3$````">N-O!_<O!N/B?/!R`+!RQN)Q0'[B<^)P2'5"=$A\0GI
MC;P/W+P;CXG9P<D;`?F+O"3(````P<X"B?4)Q0'7B>J)]2':(<4)ZHG-P<T;
MC;P7W+P;CXGJ`?J+O"3,````P<L"B=TA]0''B=@)\"'(`[0DT`````GHC;P'
MW+P;CXG0P<D"P<@;B<T!^(GWB<XAW0G>(=8#G"34````">Z-O#?<O!N/B<;!
MR@+!SAN)U0'^B=^)TR'-"<LAPP.,)-@````)ZXV\']R\&X^)\\'(`L'+&XG%
M`?N)SXG!(=4)T2'Q">F-O`_<O!N/B=G!R1L!^8N\)-P```#!S@*)]0G%`=>)
MZHGU(=HAQ0GJB<W!S1N-O!?<O!N/B>H!^HN\).````#!RP*)W2'U`<>)V`GP
M(<@#M"3D````">B-O`?<O!N/B=#!R0+!R!N)S0'XB?>)SB'="=XAU@.<).@`
M```)[HV\-]R\&X^)QL'*`L'.&XG5`?Z)WXG3(<T)RR'#">N-O!_<O!N/B?/!
MRQL!^\'(`@.,).P```")Q2'5B<^)P0G1(?$)Z8V\#]R\&X^)V<')&P'YB[PD
M\````,'.`HGU"<4!UXGJB?4AVB'%">J)S<'-&XV\%]R\&X^)Z@'ZB[PD]```
M`,'+`HG=(?4!QXG8"?`AR`.T)/@````)Z(V\!]R\&X^)T,')`L'(&XG-`?B)
M]XG.(=T)WB'6">Z-O#?<O!N/B<;!SAO!R@(!_@.<)/P```")U2'-B=^)TPG+
M(<,#C"0``0``">N-O!_<O!N/B?/!R`+!RQN)Q0'[B<^)P2'5"=$A\0GIC;P/
MW+P;CXG9P<D;`?F+O"0$`0``P<X"B?4)Q0'7B>J)]2':(<4)ZHG-P<L"P<T;
MC;P7W+P;CP'OB=T#A"0(`0``,?6)ZC'*C900UL%BRHGXP<D"P<@;B<T!T#'=
M`[0D#`$``(GJB<4Q^L'-&XVT%M;!8LJ)Z@'RB?[!S@(#G"00`0``B?<QSS''
MC;P[UL%BRHG3P<@"P<L;`?N)QP.,)!0!```Q]S'7P<H"C;PYUL%BRHG9P<D;
M`<^)T0.T)!@!```QP3'9P<L"C;0.UL%BRHGYP<D;`<Z)V0.$)!P!```QT3'Y
M`Y0D(`$``(V,"-;!8LJ)\,'(&\'/`@'!B?@QWS'WB<W!S@+!S1N-O#K6P6+*
M`>^)]0.<)"0!```QQ8GJB?TQRL'-&\')`HV<$];!8LJ)Z@':B<L#A"0H`0``
M,?,Q^\'/`HV<&-;!8LJ)T,'(&P'#B?@#M"0L`0``,<@QT,'*`HVT!M;!8LJ)
MV,'(&P'PB=8#C"0P`0``,?XQWL'+`HVT,=;!8LJ)P<')&P'.B=D#O"0T`0``
M,=$QP<'(`HV\#];!8LJ)\<')&P'YB<<#E"0X`0``,=\Q]XG-P<T;C;PZUL%B
MRL'.`@'OB?4#G"0\`0``,<6)ZHG],<K!S1O!R0*-G!/6P6+*B>H!VHG+`X0D
M0`$``#'S,?O!SP*-G!C6P6+*B=#!R!L!PXGX`[0D1`$``#'(,=#!R@*-M`;6
MP6+*B=C!R!L!\(G6`XPD2`$``#'^,=[!RP*-M#'6P6+*B<'!R1L!\8G>`[PD
M3`$``#'6,<;!R`*-O#?6P6+*B<[!SAL!_HG'`Y0D4`$``(GU,=\QS\'-&XV\
M.M;!8LJ)ZHML)`P#K"14`0```?K!R0*-O"O6P6+*B<TQQ8GKB=4Q\P'[BWPD
M",'-&P'KP<X"B1^+'"0#5"00`TPD!`-$)!2)5P2-%!Z)5PB)3PR)1Q"!Q%@!
M``!;7E]=PXUT)@"-O"<`````55=6B<93@^PLA<")5"0<=$NA0$$%"(7`B40D
M&'0^#[8&/#UU0S';BT0D&(LHA>UT*XG'D(UT)@")7"0(B70D!(DL).@X\?__
MA<!U!X!\'0`]="V#QP2++X7M==R#Q"PQP%M>7UW#9I"$P'2YB?.#PP$/M@,\
M/70$A,!U\BGSZZ>+1"0<B?DK3"08P?D"B0B#Q"R-1!T!6UY?7<.0C70F`%.)
MPX/L&(U4)`R)V.A/____A<!T-HUV`*%`004(BU0D#(T4D(M*!(7)B0ITV8UV
M`(/"!(M*!(7)B0IU](U4)`R)V.@9____A<!US8/$&%O#55>)QU8QP%.)TX/L
M/(`Z/0^4P`'#B1PDZ,/N__^-5"0LB<6)^.CF_O__A<")Q@^$W````(D$).BD
M[O__.<4/AK0```"+1"0LC0R%``````^V!SP]#X1F`0``A,`/A%X!``")^.L&
M9I"$TG0+@\`!#[80@/H]=?$I^(LU0$$%"(U$*`*)!"0!SNCC[?__A<")!@^$
M/`$``*%`004(C4\!BU0D+(L4D`^V!X3`B`)U&>L;C;0F`````(/!`0^V0?^#
MP@&$P(@"=`0\/77LQ@(],<"-M"8`````#[8,`XA,`@&#P`&$R77Q,<"#Q#Q;
M7E]=PXVT)@````"#PP$/MD/_@\8!A,"(1O]U[^O<D(UT)@"+%4!!!0B+`H7`
M#X2G````,?:-M@````"#Q@&+!+*%P'7VC02U"````(L-8%$%"(7)="V)1"0$
MB10DZ!'M__^%P*-`004(='N-#+4`````QT2P!`````")="0LZ=_^__^)!"2)
M5"08QP5@404(`0```.CJ[/__A<!T28M4)!B-#+4`````B4PD"(D$)(E,)!R)
M5"0$B40D&.A3Z___BT0D&(M,)!RC0$$%".NCC70F`#'`Z;+^__^X"````#'V
MZ6;___^X_____^D,____C78`55=6B<93@>R,````A<!T!8`X`'4+@<2,````
M6UY?7<.)!"3HZ.[__X7`B<=TYXD\).A*[O__A<")PP^$L````(![$RX/A,8`
M``")-"2-:Q/HJ^S__XDL)(E$)!SHG^S__XM,)!R-1`$"B00DZ!_L__^);"04
MB70D$,=$)`Q@R`0(QT0D"/_____'1"0$`0```(D$)(G#Z(7N__^-1"0@B40D
M"(E<)`3'!"0#````Z`WN__^#^/]T$(M$)#`E`/```#T`0```='")'"3H\.K_
M_XD<).A8ZO__B3PDZ*#M__^%P(G##X56____C;8`````B3PDZ`CN__^)-"3H
M<.K__X'$C````%M>7UW#D(UT)@`/MD,4A,`/A!+___\\+@^%)O___X![%0`/
MA`#___]FD.D5____C78`B=CHP?[__Y#KCHVT)@````"-O"<`````5E.#[!2A
M2$$%"(D$).AN[?__BT!TBW`$H4A!!0B)!"3H6^W__P^V6&&A2$$%"(/C?XD$
M).A'[?__BT`$#[=`$,'@!PG89HE&`J%(004(B00DZ"KM__^+0'2+6`2A2$$%
M"(D$).@7[?__QT0D"`````#'1"0$/\H$"(D$).A?Z___B4,<H4A!!0B)!"3H
M[^S__XM`=(M8!*%(004(B00DZ-SL__^+@/`#``")0R"A2$$%"(D$).C&[/__
MBT!TBU@$H4A!!0B)!"3HL^S__S'2BX`,`0``A<!T%J%(004(B00DZ)KL__^+
M@`P!``"+4'"A2$$%"(E3)(D$).B![/__BT!TBT`$QT`H`````*%(004(B00D
MZ&?L__^+0'2+0`3'0!@`````H4A!!0B)!"3H3>S__XM`=(M8!*%(004(B00D
MZ#KL__^+@!@"``")0RR#Q!1;7L.-="8`C;PG`````%.)PX/L&*%(004(B00D
MZ`WL__^)7"0$QP0D`P````48`0``B40D".@$[/__A<!T"(/$&#'`6\.0H4A!
M!0B)!"3HV^O__XN`*`$``"4`\```/0!```!T'Z%(004(B00DZ+SK__^+@"@!
M```E`/```#T`H```=;J)'"3'1"0$`@```.C:ZO__A<`/E,"#Q!@/ML!;PXVV
M`````(V\)P````!5B=57B<=64X'L+!```(UT)!S'1"0(_P\``(ET)`3'!"1F
MR`0(9:$4````B80D'!```#'`Z&?H__^%P'YKC5C_@'P<'`!T68G#B5PD",=$
M)`0O````B30DZ`/J__^%P'1'H4A!!0B)!"3H$NO__XE<)`R)="0(B7PD!(D$
M).B.ZO__BX0D'!```&4S!10```!U-8'$+!```%M>7UW#C78`A=MUI8UT)@"A
M2$$%"(D$).C+ZO__B6PD"(E\)`2)!"3HZ^?__^N[Z(3G__^-="8`@^P<H4A!
M!0B)!"3HH.K__\=$)`QUR`0(QT0D"+"6!`C'1"0$?\@$"(D$).@`Z?__@\0<
MPXVV`````(V_`````(/L+*%(004(B00DZ&#J__^)!"3HJ/___Z%(004(B00D
MZ$OJ___'1"04`````,=$)!`_R@0(QT0D##_*!`C'1"0(D,($",=$)`2;R`0(
MB00DZ$OI__^#Q"S#C;0F`````%=64X'L,"```&6A%````(F$)"P@```QP(U<
M)"KH?^?__\=$)!1QR`0(QT0D#+#(!`C'1"0(`1```,=$)`0!````B1PDB40D
M$.@3ZO__A<!X9XV\)"L0``")'"3'1"0(`!```(E\)`3HQ.;__X7`B<-X1HU`
M`8D$).A3Y___A<")QG0UB5PD"(E\)`2)!"3H[>7__XGPQ@0>`(N4)"P@``!E
M,Q44````=1.!Q#`@``!;7E_#D(UT)@`QP.O=Z!_F___K#9"0D)"0D)"0D)"0
MD)#I*____XUT)@"-O"<`````55=64X'L/!```&6A%````(F$)"P0```QP(U4
M)"BXOL@$"(NT)%`0``"+O"14$```Z%OW___'1"0$+P```(DT)(G#Z/GF__^%
MP'0MB?*XQ\@$".@I^/__B?"+E"0L$```93,5%`````^%3@$``('$/!```%M>
M7UW#B30DZ.#F__^)/"2-?"0LQT0D!-3(!`B)1"0<Z/CG__^)Q8VV`````(7M
M=*>`?0``=06]O,@$"(7;=!2);"0$B1PDZ)'D__^%P`^$K````(DL).B1YO__
M@'P%_R]U$6:0@^@!@'P%_R_&1`4``'3QBTPD'(U$"`$]_P\```^/4?___XET
M)!C'1"04UL@$"(EL)!#'1"0,^LD$",=$)`@`$```QT0D!`$```")/"3H5NC_
M_Z%(004(B00DZ/GG__^)?"0$QP0D`P````48`0``B40D".C0Y___A<!U'Z%(
M004(B00DZ,_G__^+@"@!```E`/```#T`@```=!O'1"0$U,@$",<$)`````#H
M">?__XG%Z1+____'1"0$`0```(D\).C2YO__A<!UT8GZN,?(!`CHTO;__XD\
M).@JYO__Z9[^__^0C70F`.@[Y/__C70F`(V\)P````"+1"0$#[8(A,ET((U0
M`>L*#[8*@\(!A,ET$8#Y+W7Q#[8*B="#P@&$R77O\\.-=@!3@^P8BUPD((7;
M=#R`.P!T-XD<).A'Y?__C40#_SG#<@[K49"-="8`@^@!.=AT"8`X+W3TZS=F
MD(`X+Y"-="8`#X6)````9I#'!"0"````Z)SD__^%P'1PNBX```!FB1"#Q!A;
MPXUV`(`X+W0'@^@!.<-R]#G8=0WKOHVV`````(`X+W4'@^@!.<-R]"G8C5`"
M@?H`$```=R^#P`&)7"0$QT0D#``0``")1"0(QP0D8$$%".B(Y?__@\08N&!!
M!0A;PXVV`````(/$&#'`6\/'1"0@UL@$"(/$&%OI`.7__U=6@^PT9:$4````
MB40D+#'`H4S*!`B)1"0*H5#*!`B)1"0.H53*!`B)1"02H5C*!`B)1"06H5S*
M!`B)1"0:H6#*!`B)1"0>H63*!`B)1"0BH6C*!`B)1"0F#[<%;,H$"&:)1"0J
MN-C(!`CHX?3__[CAR`0(Z-?T__^XZ<@$".C-]/__N/+(!`CHP_3__[CYR`0(
MZ+GT__^X"<D$".BO]/__N+[(!`CHI?3__[@5R00(Z)OT__^X'\D$".B1]/__
MN"G)!`CHA_3__[C'R`0(Z'WT__^X,\D$".AS]/__N#S)!`CH:?3__XU4)`2X
M1\D$".B[\___A<!T#(G"N!_)!`CHF_3__XU4)`2X6,D$".B=\___A<!T#(G"
MN&K)!`CH??3__XU4)`2X=<D$".A_\___A<!T,XG"N+[(!`CH7_3__[JAR00(
MN/G(!`CH4/3__XM$)"QE,P44````=4V#Q#1>7\.0C70F`(U4)`2XA<D$".@Z
M\___A<!T#HG"N!7)!`CH&O3__^NYC70D&[^6R00(N0H```#SIG6GC50D);@5
MR00(Z/CS___KE^AQX?__D*$H004(@_C_=`;#D(UT)@"#[!RX%<D$"(U4)`SH
MW_+__X7`=!L/MA`QP(32=`@QP(#Z,`^5P*,H004(@\0<PY`QP.ORC;8`````
MC;\`````@^P<Z"CA__^)!"3H@.#__X7`=`R+`(/$',.-M@`````QP.ORC;8`
M````C;\`````55>_K<D$"%93NZ/)!`B#[$S'1"0DK<D$"(UT)"S'1"0HH\D$
M",=$)"RPR00(QT0D,*;)!`C'1"0TJ\D$",=$)#B]R00(QT0D/`````#K(I"+
M1"1@B2PDB40D!.C0W___A<!T/(7;="Z+!HG?@\8$B<.-5"0@B?CH!/+__X7`
MB<5T!8`X`'7)BU0D8(GXZ-[R__^%VW72@\1,6UY?7<-FD(M$)&")!"3HI.'_
M_XDL)(E$)!SHF.'__XM4)!R-1`("B00DZ!CA__^);"08QT0D%-3(!`C'1"0,
M^LD$",=$)`C_____QT0D!`$```")PHM$)&")%"2)5"0<B40D$.ANX___BU0D
M'(GXZ&/R___I4O___XVT)@````"-O"<`````55=64X'L'($``(N$)#"!``"-
M5"0XQT0D/-3)!`C'1"1`O,@$",=$)$0`````B40D*&6A%````(F$)`R!```Q
MP+B^R`0(QT0D5&K)!`C'1"188\D$",=$)%S9R00(QT0D8(#)!`C'1"1DX<D$
M",=$)&@`````QT0D2,C)!`C'1"1,Y<D$",=$)%``````Z,[P__^%P'0)@#@`
M#X5)!```D.@+_O__A<")PP^$5@0``(D<).AYX/__C40``8D$).C]W___@#L`
MB<:)QW0VC70F``^V`X/#`8D\)(/'`L=$)`SNR00(QT0D"/____^)1"00QT0D
M!`$```#H4^+__X`[`'7.C7PD6+AJR00(ZPV-=@"#QP2+1_R%P'0NC50D..@]
M\/__A<")PW3G@#@`=.+HK?7__X7`=-F)'"3H<>#__X7`B<5U38UV`(M<)#R%
MVW1`@#L`OP$```!U%NLTC70F`(M<O#R%VW0H@\<!@#L`="")V.AI]?__A<!T
MY8D<).@MX/__A<!TV8G%ZP>0C70F`#'MB2PDB?/HE-___XL+@\,$C9'__O[^
M]]$ARH'B@("`@'3I]\*`@```=0;!ZA"#PP(`TH/;`RGSC9P#!`0``(D<).CI
MWO__B70D',=$)!CSR00(QT0D%-;(!`B);"00QT0D#/C)!`B)QL=$)`C_____
MQT0D!`$```")!"2)1"0DZ#OA___'1"0$P`$``(DT).A[W___@_C_#X2"````
MH4A!!0B)!"3HQ>#__\<$)`,````%&`$``(E$)`B+1"0DB40D!.BXX/__A<`/
MA)@```"+1"0DB40D$(M$)"B+`,=$)`BLR@0(QT0D!`$```")1"0,H41!!0B)
M!"3H,>#__S'`BXPD#($``&4S#10````/A;L(``"!Q!R!``!;7E]=P^@;W___
MBP"#^!$/A&[___^)1"04BT0D)(E$)!"+1"0HBP#'1"0(<,H$",=$)`0!````
MB40D#*%$004(B00DZ,W?__\QP.N:D*%(004(B00DZ/O?__^+@"@!```E`/``
M`#T`0```#X5%____H4A!!0B)!"3HV-___XNP,`$``.BMW/__.<8/A27___^A
M2$$%"(D$).BXW___BX`H`0``)?\!```]P`$```^%`O___XD<).A:W?__C50D
M.(G%N*;)!`CHZNW__X7`#X3G!P``B00DZ"K>__^)1"0$BT0D*(L`B00DZ#CV
M__^%P(G##X3#!P``B1PDZ(;=__^#^`-^*8UT`_R_`<H$"+D%````\Z9U%X/X
M!`^$?P8``(!\`_LO#X1T!@``C78`Z(/Z__^%P'4<QT0D!`````")'"3H7]W_
M_X7`B40D*`^%5P$``+JAR00(N!7)!`CH1.[__S';Z'W<__^+="0DQT0D'#_*
M!`C'1"04UL@$",=$)`P:R@0(B70D$,=$)`C_____B40D&,=$)`0!````B2PD
MZ`'?___K58VT)@````#H<]W__X,X$759Z"G<__^#PP''1"0@/\H$"(E<)!S'
M1"04UL@$"(ET)!#'1"0,*,H$"(E$)!C'1"0(_____\=$)`0!````B2PDZ*K>
M___'1"0$P`$``(DL).CJW/__@_C_=)V+1"0DB00DZ)G:__^)ZKB^R`0(Z'WM
M__^)+"3H!?K__XGHZ:_]__^-M@````")!"2)1"0DZ.SY__^+1"0DB00DZ+#<
M___IC/W__[X!````N,C)!`CK$HVT)@````"+1+1(@\8!A<!T)8U4)#CH-.S_
M_X7`=.B`.`!TXXD$).ASW/__A<!TUXG#Z6?[__^P#;O-R00(Z6?[___'1"0,
M`@```(G&QT0D!.[____'1"0(_____XD$).@*V___C80D#`$``,=$)`@&````
MB40D!(DT).B?V?__@+PD#`$```!U#H"\)`T!``!##X0J!0``BT0D*,=$)`P`
M````QT0D!`````#'1"0(`````(D$).BSVO__QX0DK`````$C16?'A"2P````
MB:O-[\>$)+0```#^W+J8QX0DN````'94,A#'A"2\````\.'2P\>$),``````
M````QX0DQ`````````#'A"0(`0```````(EL)"R-M"8`````C80D#`$``(E$
M)`2+1"0HQT0D"`"```")!"3HX=C__X7`B<8/CLX!``"+E"3`````C03R.<(/
MAZT!``"+E"3$````B80DP````(GPP>@=`=")A"3$````BX0D"`$``(7`#X1R
M`0``ND````")]RG".=9^`HG7C80$R````(V,)`P!``")?"0(B4PD!(D$).BM
MV/__BX0D"`$```'X@_A`B80D"`$```^%5/___XV$)`P!```I_@''C80DK```
M`.A-W___D(UT)@"#_C\/CM8```")]8G[C78`BP.#[4"#PT")A"3(````BT/$
MB80DS````(M#R(F$)-````"+0\R)A"34````BT/0B80DV````(M#U(F$)-P`
M``"+0]B)A"3@````BT/<B80DY````(M#X(F$).@```"+0^2)A"3L````BT/H
MB80D\````(M#[(F$)/0```"+0_")A"3X````BT/TB80D_````(M#^(F$)``!
M``"+0_R)A"0$`0``C80DK````.B'WO__@_T_#X]&____@^Y`B?+!Z@:-0@'!
MX`;!X@8!QRG6C80DR````,=$)`Q$````B70D"(E\)`2)!"3HZMC__XFT)`@!
M``#I+O[__XVV`````(V\)`P!``#IY/[__XUT)@"+C"3$````C5$!Z4O^__^+
M1"0HBVPD+(D$).CIVO__BYPDP````(NT),0```")V,'H`X/@/XU0`8/Z.,:$
M!,@```"`#X\M`@``NC<````IPHV$!,D```")5"0(QT0D!`````")!"3H#=G_
M_XGPP>@8B(0D``$``(GPP>@0B(0D`0$``(GPP>@(B(0D`@$``(GPB(0D`P$`
M`(G8P>@8B(0D!`$``(G8P>@0B(0D!0$``(G8P>@(B(0D!@$``(V$)*P```"(
MG"0'`0``C;PD@P```.A2W?__BY0DK````(UT)'"-G"2K````B='!Z1@/ML&(
M3"1OB='!Z1"(3"1PB=&(5"1RBY0DL````,'I"(A,)'&)T<'I&(A,)'.)T<'I
M$(A,)'2)T8A4)':+E"2T````P>D(B$PD=8G1P>D8B$PD=XG1P>D0B$PD>(G1
MB%0D>HN4)+@```#!Z0B(3"1YB='!Z1B(3"1[B='!Z1"(3"1\B=&(5"1^BY0D
MO````,'I"(A,)'V)T<'I&(A,)'^)T<'I$(B,)(````")T<'I"(B,)($```"(
ME"2"````Z08````/M@:#Q@&)/"2#QP*)1"00QT0D#.[)!`C'1"0(_____\=$
M)`0!````Z%O9__\YWW7/QH0DJP````"-A"2#````QT0D'#_*!`B)1"08BT0D
M),=$)!36R`0(QT0D#`O*!`C'1"0(_____XE$)!#'1"0$`0```(DL).@,V?__
MZ7+Z__^+1"0HBU`$A=(/A(#Y__^)%"2)5"0HZ,S6__^+5"0H@_@##X9G^?__
MC70"_+\&R@0(N04```#SI@^%4?G__XG3Z4KY__^Z/P```"G"C80$R0```(E4
M)`C'1"0$`````(D$).C@UO__C80DK````.B$V___C90DR````+D.````,<")
MU_.KZ;#]__^`O"0.`0``00^%R/K__X"\)`\!``!##X6Z^O__@+PD$`$``$@/
MA:SZ__^`O"01`0``10^%GOK__XMT)"C'1"0,`@```,=$)`3&____QT0D"/__
M__^)-"3H4=7__XV$)`P!``#'1"0(*0```(E$)`2)-"3HYM/__XV$)`P!``#'
M1"0</\H$".FR_O__9I#H:]3__XM$)"B+&.DR^/__55=64X/L+*%(004(B00D
MZ'S7__^-5"0<QD!=`;CYR`0(Z,KE__^%P'0)@#@Q#X2M`@``Z`CQ__^A2$$%
M"(D$).A+U___QT0D#`L```#'1"0(`0```,=$)`0YR@0(B00DZ/O4__^%P`^$
MRP```(M`#(,]:%$%"`&+>!@/CK@````Q]KL!````ZS&-M"8`````BT4,B40D
M!*%D404(BP28B00DZ`G3__^%P'5]H6A1!0B#PP&#Q@$YV'YSH4A!!0B)!"3H
MR=;__\=$)`P`````B70D"(E\)`2)!"3H(=;__X7`=$6+*(M%""4`!"``/0`$
M``!TG*%(004(B00DZ(_6___'1"0,`@```,=$)`@`````B6PD!(D$).BST___
MZ7'___^-M@````"A:%$%"(U0_SGR#X1(`0``H4A!!0B)!"3H2];__\=$)`P$
M````QT0D"`$```#'1"0$/LH$"(D$).C[T___A<")PW0UBT`,BS"A2$$%"(D$
M).@3UO__QT0D"$#*!`B)="0$B00DZ"_3__^+0PR+&/9#"D`/A2`!``"A2$$%
M"(D$).CCU?__QT0D#`0```#'1"0(`0```,=$)`1%R00(B00DZ)/3__^%P(G&
M=#J-5"0<N,?(!`CH#^3__X7`B<,/A)4!``"+1@R+.*%(004(B00DZ)/5__^)
M7"0(B7PD!(D$).BSTO__H4A!!0B)!"3H=M7__\9`70"A2$$%"(D$).AEU?__
MC50D',>`<`0```````"XOL@$".BMX___A<")PZ-L404(#X2F````QT0D!,`!
M``")!"3HSM/__X/X$70,C5`!@_H!#X>9`0``@\0L6UY?7<.0C70F`(/X`0^.
MK_[__[L!````9I"A2$$%"(/#`8D$).CPU/__B7PD!(D$).ADT?__.1UH404(
M?]SI?_[__XVT)@````"A2$$%"(D$).C#U/__B5PD!(D$).BWT___Z<+^__]F
MD(!X`0`/A$[]__^-M@````#I/OW__XUV`*%D404(B00DZ(OQ__^%P*-L404(
M#X3N````BT8,BSUD404(BQB+0P@E``0@`#T`!```#X6B````BT,,B7PD!(D$
M).AAT?__B<>+1@R+&(M3"('B``0@`('Z``0``'50BT,,B40D"*%D404(B7PD
M#(L`QP0D),L$"(E$)`3HA]+__XVT)@````"A9%$%"(LXBT8,BQBA2$$%"(D$
M).CWT___B?J)V.ANZ/__Z6;^__^A2$$%"(D$).C<T___QT0D#`(```#'1"0(
M`````(E<)`2)!"3H`-'__^N(H4A!!0B)!"3HL=/__\=$)`P"````QT0D"```
M``")7"0$B00DZ-70___I,____\<$)`#+!`CH]-'__XE$)`RA9%$%"(E<)`B+
M`,<$)$S+!`B)1"0$Z-71__^0C70F`%93@^P4BW0D((DT).@?[/__#[8(B<.$
MR70AC5`!ZPN0#[8*@\(!A,ET$8#Y+W7Q#[8*B=.#P@&$R77OZ(#N__^%P'0=
MA?9T&8`^`'04QT0D!//)!`B)'"3H$\___SG8=`:#Q!1;7L.#Q!2)\%M>Z1WD
M__^-M@````"-O"<`````@^P<H4A!!0B)!"3HT-+__\=$)`3_____B00DZ"#0
M__^A2$$%"(D$).BSTO__QT0D"`````#'1"0$H*P$"(D$).AKTO__@\0<PV:0
M9I!FD)!3Z/K4__^!PVIX``"#[!B+@R0!``")1"0,BT0D*(E$)`B+1"0DB40D
M!(M$)"")!"3HR\___X/$&%O#9I!FD&:055<Q_U93Z+74__^!PR5X``"#[!R+
M;"0PC;/D_O__Z`G.__^-@^#^__\IQL'^`H7V=">-M@````"+1"0XB2PDB40D
M"(M$)#2)1"0$_Y2[X/[__X/'`3GW==^#Q!Q;7E]=P^L-D)"0D)"0D)"0D)"0
MD//#9I!3@^P(Z$/4__^!P[-W``"#Q`A;PP,````!``(`)7,O)7,`+W!R;V,O
M<V5L9B]E>&4`<&5R;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P`N`%!!4E]414U0
M`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!0
M15),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!0
M05)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,
M3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,24)0
M051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!5$@`55-%4@!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`
M<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P!!4D=6`!@`<&5R;``M90`M+0``7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("``````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``56YA8FQE('1O(&-R96%T
M92!C86-H92!D:7)E8W1O<GD`````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL
M960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````(R$O=7-R
M+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S
M="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U
M<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA
M;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@
M("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C
M($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A
M8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S
M=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN
M9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y
M<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N
M;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T
M86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U
M;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N
M;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O
M;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT
M('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG
M('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP
M*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@
M("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.
M3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A
M+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M
M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T
M:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*
M("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@
M("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF
M,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD
M*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF
M:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.
M5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!
M4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%2
M7T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS
M92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6
M>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F
M<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R
M7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T
M:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*
M("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T
M:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0[
M"B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(
M+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE
M<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@
M,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M
M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0[
M"@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*
M("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@
M("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L
M;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@
M(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA
M;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@
M("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@
M("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@
M("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP
M;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M
M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D
M;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@
M("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@
M("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE
M)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO
M9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@
M/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@
M("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@
M("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@
M(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@
M("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER
M95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D
M=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD
M:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*
M("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M
M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M
M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@
M("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D
M9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P
M<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C
M;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@
M)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@
M("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@
M)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L
M;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@
M;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R
M97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I
M;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z
M.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W
M:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T
M*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,
M15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@
M("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE
M(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C
M(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@
M("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@
M("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<
M,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*
M(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@ID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F
M;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS
M"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO
M;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@
M("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@
M("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*
M("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H92!A
M<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM<F5U
M<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@=&\@
M<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN9R!F
M<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P('1H
M92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S:&EF
M="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@*$!!
M4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@97$@
M)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2![
M"B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@("`@
M("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@("`D
M;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2![
M"B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@
M("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I
M('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@("`@
M(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("`@
M("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@("!I
M;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0[
M"B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P
M<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM[
M"FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R
M97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP
M.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D
M>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M
M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@
M)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O
M<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY
M("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@
M)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O
M7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@
M86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@
M:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P
M87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@
M("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q0
M05(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O
M=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@
M("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@
M,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@
M("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E
M9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA
M<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A
M9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A
M;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D
M=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B
M7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E
M="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A
M9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S
M970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@
M("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D
M+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D
M=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!0
M05(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO
M9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@
M("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*
M("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@
M("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@
M("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@
M("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T
M;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN
M9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S
M<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET
M:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M
M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N
M9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM
M(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD
M+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@
M("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@
M("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@
M("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@
M("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2![
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@
M("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@
M("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@
M("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=
M*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N
M9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@
M(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@
M("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H
M4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE
M+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@
M("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F
M:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U
M9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O
M<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I
M.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@
M("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@
M("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@
M("!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R
M8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@
M("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D
M8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO
M=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@
M("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O
M<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^
M861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F
M:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!
M0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D[
M"B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E
M.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*
M?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A
M8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!
M4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@
M<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@
M1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@
M('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F
M:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP
M.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q
M*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@
M("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@
M("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M
M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@
M("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN
M8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@
M("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?
M;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN
M<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]
M?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@
M"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@[
M"B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*
M("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*
M("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@
M(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@
M0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q
M=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I
M<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U
M:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I
M<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@
M<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E
M<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["B`@("!R97%U:7)E(&%T=')I8G5T
M97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U
M:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@
M?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z
M.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P
M<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI
M=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U
M8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D
M<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R
M96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@
M<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@
M("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L
M('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@
M("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@
M("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@
M("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@
M)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]
M("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E
M<FYA;64I.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@
M(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\
M(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*
M("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@
M("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@
M<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H
M+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*
M("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@
M("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@
M("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z
M.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R
M;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F
M:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@
M*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@
M("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S
M=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F
M:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@
M)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D
M97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL
M:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`
M=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@
M<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*
M("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A
M.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE
M*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE
M.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E
M9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-
M17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]
M"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@
M("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I
M9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#
M;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@
M("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@
M("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([
M"B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N
M86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!0
M5T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@
M("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1
M)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@
M("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?
M:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W
M*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'
M0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]]
M.PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@
M("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@
M("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF
M("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU
M92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*
M("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@
M("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@
M("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@
M(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB
M97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@
M('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S
M8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI
M"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*
M(VQI;F4@,3`Q,0H*7U]%3D1?7PH``````````````(#____/00$;`SOH````
M'````-!N__\$`0``,'/__YP%```0=O__*`$``#"!__]H`0``T('__[P!```@
M@O__X`$```"$__\@`@``4(7__W@"``"PAO__I`(``%"'___0`@``((C__Q`#
M``!@B/__*`,``,"(__]``P``D(G__W@#``"@B?__C`,``'"+___,`P``H(O_
M_^`#``"`C/__(`0``#".__]0!```@([__VP$``"PCO__B`0``-"/___(!```
M0)O__PP%``!PG___3`4``/"?__^$!0``0*#__\@%``"`H/__Z`4``/"@__\D
M!@``%``````````!>E(``7P(`1L,!`2(`0``(````!P```#$;?__8`0````.
M"$8.#$H/"W0$>``_&CLJ,B0B/````$````#@=/__%0L```!!#@B%`D$.#(<#
M00X0A@1!#A2#!48.[`(#!@L.%$'##A!!Q@X,0<<."$'%#@0``%````"`````
MP'___YL`````00X(A0)!#@R'`T$.$(8$0PX4@P5##D`"5@H.%$/##A!!Q@X,
M0<<."$'%#@1#"VH.%$7##A!!Q@X,0<<."$'%#@0``"````#4````#(#__U``
M````00X(@P)%#B`"2`X(0<,.!````#P```#X````.(#__]T!````00X(A0)!
M#@R'`T,.$(8$0PX4@P5%#E`"WPH.%$'##A!!Q@X,0<<."$'%#@1("P!4````
M.`$``-B!__]"`0```$$."(4"00X,AP-!#A"&!$,.%(,%1@Z@`4\*#A1!PPX0
M0<8.#$''#@A!Q0X$00L"Y@H.%$'##A!!Q@X,0<<."$'%#@1&"P``*````)`!
M``#0@O__50$```!!#@B&`D$.#(,#0PX@`TT!#@Q!PPX(0<8.!``H````O`$`
M``2$__^3`````$$."(,"10X@;0H."$/##@1""P)6#@A$PPX$`#P```#H`0``
M>(3__\P`````00X(A0)##@R'`T,.$(8$00X4@P5&#L`@`HH*#A1!PPX00<8.
M#$''#@A!Q0X$1`L4````*`(```B%__\T`````$,.('`.!``4````0`(``#"%
M__]9`````$,.,`)5#@0T````6`(``'B%___!`````$$."(<"00X,A@-!#A"#
M!$8.P$`"I@H.$$'##@Q!Q@X(0<<.!$8+`!````"0`@``$(;__P4`````````
M/````*0"```,AO__Q0$```!!#@B%`D$.#(<#00X0A@1!#A2#!48.T"`":0H.
M%$'##A!!Q@X,0<<."$'%#@1!"Q````#D`@``G(?__RT`````````/````/@"
M``"XA___X`````!!#@B#`D,.(`)?"@X(0<,.!$0+`E,*#@A&PPX$1PM#"@X(
M0\,.!$$+2PX(0<,.!"P````X`P``6(C__Z\!````00X(AP)!#@R&`T,.0`-;
M`0H.#$'&#@A!QPX$1@L``!@```!H`P``V(G__T0`````4PX@:PH.!$(+```8
M````A`,```R*__\D`````$,.(%8*#@1'"P``/````*`#```@BO__$@$```!!
M#@B%`D$.#(<#1@X0A@1!#A2#!4@.8`*("@X40<,.$$'&#@Q!QPX(0<4.!$,+
M`$````#@`P```(O__W`+````00X(A0)!#@R'`T$.$(8$00X4@P5&#K""`@.A
M`@H.%$'##A!!Q@X,0<<."$'%#@1!"P``/````"0$```LEO__*P0```!!#@B%
M`D$.#(<#00X0A@1!#A2#!4,.0`-O`@H.%$'##A!!Q@X,0<<."$'%#@1&"S0`
M``!D!```')K__W,`````00X(A@)!#@R#`T,.(`)?"@X,0<,."$'&#@1!"T,.
M#$/##@A!Q@X$%````)P$``!DFO__20````!##B`"10X$*````+0$``",;?__
MY`$```!!#@B%`D(-!4B&`X,$`X@!"L-!QD'%#`0$00L<````X`0``'":__\Z
M`````$$."(,"3@X@:0X(0<,.!#@`````!0``D)K__V$`````00X(A0)!#@R'
M`T,.$(8$00X4@P5.#C`"2`X40<,.$$'&#@Q!QPX(0<4.!!`````\!0``Q)K_
M_P(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````PG00($)T$
M"``````!`````0````$````(`@```0```%<"```/````RP,``!T```#+`P``
M#````/R5!`@-````1,@$"!D```#@/@4(&P````0````:````Y#X%"!P````$
M````!````*R!!`CU_O]OY(0$"`4```#LC`0(!@```#R&!`@*````6@4```L`
M```0````%0`````````#`````$`%"`(````H`@``%````!$````7````U),$
M"!$```"LDP0($@```"@````3````"````/[__V\<DP0(____;P(```#P__]O
M1I($"```````````````````````````````````````````````````````
M``````````````#L/@4(```````````VE@0(1I8$"%:6!`AFE@0(=I8$"(:6
M!`B6E@0(II8$"+:6!`C&E@0(UI8$".:6!`CVE@0(!I<$"!:7!`@FEP0(-I<$
M"$:7!`A6EP0(9I<$"':7!`B&EP0(EI<$"*:7!`BVEP0(QI<$"-:7!`CFEP0(
M]I<$"`:8!`@6F`0()I@$"#:8!`A&F`0(5I@$"&:8!`AVF`0(AI@$"):8!`BF
MF`0(MI@$",:8!`C6F`0(YI@$"/:8!`@&F00(%ID$"":9!`@VF00(1ID$"%:9
M!`AFF00(=ID$"(:9!`B6F00(IID$"+:9!`C&F00(UID$".:9!`CVF00(!IH$
M"!::!`@FF@0(-IH$"$::!`A6F@0(9IH$"'::!`@``````````/____^0RP0(
M1T-#.B`H4U5312!,:6YU>"D@-"XX+C$@,C`Q,S`Y,#D@6V=C8RTT7S@M8G)A
M;F-H(')E=FES:6]N(#(P,C,X.%T``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E
M+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM
M`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN
M`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N
M9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`````
M``````````````````````````````````````````````````L````!````
M`@```%2!!`A4`0``$P```````````````0`````````3````!P````(```!H
M@00(:`$``"````````````````0`````````(0````<````"````B($$"(@!
M```D```````````````$`````````#@````%`````@```*R!!`BL`0``.`,`
M``8`````````!`````0````T````]O__;P(```#DA`0(Y`0``%@!```&````
M``````0````$````/@````L````"````/(8$"#P&``"P!@``!P````$````$
M````$````$8````#`````@```.R,!`CL#```6@4``````````````0``````
M``!.````____;P(```!&D@0(1A(``-8````&``````````(````"````6P``
M`/[__V\"````'),$"!P3``"0````!P````(````$`````````&H````)````
M`@```*R3!`BL$P``*`````8`````````!`````@```!S````"0````(```#4
MDP0(U!,``"@"```&````#0````0````(````?`````$````&````_)4$"/P5
M```C```````````````$`````````'<````!````!@```""6!`@@%@``8`0`
M````````````$`````0```""`````0````8```"`F@0(@!H``,0M````````
M`````!``````````B`````$````&````1,@$"$1(```4```````````````$
M`````````(X````!`````@```%C(!`A82```^%X`````````````"```````
M``"6`````0````(```!0)P4(4*<``.P```````````````0`````````I```
M``$````"````/"@%"#RH``!0!0`````````````$`````````*X````.````
M`P```.`^!0C@K@``!```````````````!`````````"Z````#P````,```#D
M/@4(Y*X```0```````````````0`````````Q@````$````#````Z#X%".BN
M```$```````````````$`````````,L````&`````P```.P^!0CLK@``$`$`
M``<`````````!`````@```#4`````0````,```#\/P4(_*\```0`````````
M``````0````$````V0````$````#`````$`%"`"P```@`0`````````````$
M````!````.(````!`````P```"!!!0@@L0``$```````````````!```````
M``#H````"`````,```!`004(,+$``#00`````````````"``````````[0``
M``$````P`````````#"Q``!"```````````````!`````0````$````#````
@``````````!RL0``]@```````````````0``````````
